The core API for recursive maps.
The core API for recursive maps.
(->rmap m)Takes an associative datastructure m and returns m where each of the
values are wrapped with rval.
Takes an associative datastructure m and returns m where each of the values are wrapped with [[rval]].
(ref-tag key)A tagged literal processor, for use with clojure.edn/read-string.
(clojure.edn/read-string {:readers {'rmap/ref rmap.core/ref-tag}} "{:foo 1 :bar #rmap/ref :foo}")
A tagged literal processor, for use with clojure.edn/read-string.
(clojure.edn/read-string {:readers {'rmap/ref rmap.core/ref-tag}}
"{:foo 1 :bar #rmap/ref :foo}")(rmap m)Takes a literal associative datastructure m and returns m where each
of the value expressions are wrapped with rval.
Takes a literal associative datastructure m and returns m where each of the value expressions are wrapped with [[rval]].
(rval & body)Takes a body of expressions and yields an RVal object. The body has
implicit access to a (fn ref [key] [key not-found]) function and
is not evaluated yet.
Takes a body of expressions and yields an RVal object. The body has implicit access to a `(fn ref [key] [key not-found])` function and is not evaluated yet.
(valuate! m)(valuate! m f)Given associative datastructure m, returns m where all RVal values are evaluated. Takes an optional post-evaluation wrapper function.
Given associative datastructure m, returns m where all RVal values are evaluated. Takes an optional post-evaluation wrapper function.
(valuate-keys! m & keys)Given associative datastructure m, returns m where all RVal values under the given keys and their dependencies are evaluated.
Given associative datastructure m, returns m where all RVal values under the given keys and their dependencies are evaluated.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |